==> 2.6.0.tar.gz: lib/zego_uikit_signaling_plugin.dart <==
// Dart imports:
import 'dart:async';
import 'dart:convert';
import 'dart:io' as io;

// Flutter imports:
import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:flutter/services.dart';

// Package imports:
import 'package:zego_plugin_adapter/zego_plugin_adapter.dart';
import 'package:zego_zim/zego_zim.dart';
import 'package:zego_zpns/zego_zpns.dart';

// Project imports:
import 'package:zego_uikit_signaling_plugin/src/channel/platform_interface.dart';
import 'package:zego_uikit_signaling_plugin/src/internal/core.dart';
import 'package:zego_uikit_signaling_plugin/src/internal/event_center.dart';
import 'package:zego_uikit_signaling_plugin/src/log/logger_service.dart';

export 'package:zego_zim/zego_zim.dart' hide ZIMEventHandler;

part 'src/invitation.dart';

part 'src/message.dart';

part 'src/notification.dart';

part 'src/room.dart';

part 'src/user.dart';

part 'src/background_message.dart';

part 'src/callkit.dart';

/// @nodoc
class ZegoUIKitSignalingPlugin
    with
        ZegoSignalingPluginRoomAPIImpl,
        ZegoSignalingPluginRoomEventImpl,
        ZegoSignalingPluginInvitationAPIImpl,
        ZegoSignalingPluginInvitationEventImpl,
        ZegoSignalingPluginUserAPIImpl,
        ZegoSignalingPluginUserEventImpl,
        ZegoSignalingPluginNotificationAPIImpl,
        ZegoSignalingPluginNotificationEventImpl,
        ZegoSignalingPluginMessageAPIImpl,
        ZegoSignalingPluginMessageEventImpl,
        ZegoSignalingPluginBackgroundMessageAPIImpl,
        ZegoSignalingPluginBackgroundMessageEventImpl,
        ZegoSignalingPluginCallKitAPIImpl,
        ZegoSignalingPluginCallKitEventImpl,
        IZegoUIKitPlugin
    implements ZegoSignalingPluginInterface {
  ZegoSignalingPluginEventCenter get eventCenter =>
      ZegoSignalingPluginCore().eventCenter;

  factory ZegoUIKitSignalingPlugin() => instance;

  ZegoUIKitSignalingPlugin._();

  static final ZegoUIKitSignalingPlugin instance = ZegoUIKitSignalingPlugin._();

  @override
  ZegoUIKitPluginType getPluginType() => ZegoUIKitPluginType.signaling;

  @override
  Future<String> getVersion() async {
    final zimVersion = await ZIM.getVersion();
    const signalingVersion = 'zego_uikit_signaling_plugin: 2.6.0;';
    if (!kIsWeb && (io.Platform.isAndroid || io.Platform.isIOS)) {
      final zpnsVersion = await ZPNs.getVersion();
      return '$signalingVersion zim:$zimVersion; zpns:$zpnsVersion;';
    } else {
      return '$signalingVersion zim:$zimVersion;';
    }
  }

  @override
  Future<void> init({required int appID, String appSign = ''}) async {
    await ZegoSignalingLoggerService().initLog();

    ZegoSignalingLoggerService.logInfo(
      'create ZIM',
      tag: 'signaling',
      subTag: 'init',
    );

    if (null != ZIM.getInstance()) {
      ZegoSignalingLoggerService.logInfo(
        'ZIM is create before',
        tag: 'signaling',
        subTag: 'init',
      );

      return;
    }

    ZIM.create(ZIMAppConfig()
      ..appID = appID
      ..appSign = appSign);
  }

  @override
  Future<void> uninit() async {
    ZegoSignalingLoggerService.logInfo(
      'destroy ZIM',
      tag: 'signaling',
      subTag: 'uninit',
    );

    ZIM.getInstance()?.destroy();
  }

  @override
  Stream<ZegoSignalingPluginErrorEvent> getErrorEventStream() {
    return ZegoSignalingPluginCore().eventCenter.errorEvent.stream;
  }

  @override
  Stream<ZegoSignalingError> getErrorStream() {
    return ZegoSignalingPluginCore().errorStreamCtrl.stream;
  }
}

==> 2.6.5.tar.gz: lib/zego_uikit_signaling_plugin.dart <==
// Dart imports:
import 'dart:async';
import 'dart:io' as io;

// Flutter imports:
import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:flutter/services.dart';

// Package imports:
import 'package:zego_plugin_adapter/zego_plugin_adapter.dart';
import 'package:zego_zim/zego_zim.dart';
import 'package:zego_zpns/zego_zpns.dart';

// Project imports:
import 'package:zego_uikit_signaling_plugin/src/internal/core.dart';
import 'package:zego_uikit_signaling_plugin/src/internal/event_center.dart';
import 'package:zego_uikit_signaling_plugin/src/log/logger_service.dart';

export 'package:zego_zim/zego_zim.dart' hide ZIMEventHandler;

part 'src/invitation.dart';

part 'src/message.dart';

part 'src/notification.dart';

part 'src/room.dart';

part 'src/user.dart';

part 'src/background_message.dart';

part 'src/callkit.dart';

/// @nodoc
class ZegoUIKitSignalingPlugin
    with
        ZegoSignalingPluginRoomAPIImpl,
        ZegoSignalingPluginRoomEventImpl,
        ZegoSignalingPluginInvitationAPIImpl,
        ZegoSignalingPluginInvitationEventImpl,
        ZegoSignalingPluginUserAPIImpl,
        ZegoSignalingPluginUserEventImpl,
        ZegoSignalingPluginNotificationAPIImpl,
        ZegoSignalingPluginNotificationEventImpl,
        ZegoSignalingPluginMessageAPIImpl,
        ZegoSignalingPluginMessageEventImpl,
        ZegoSignalingPluginBackgroundMessageAPIImpl,
        ZegoSignalingPluginBackgroundMessageEventImpl,
        ZegoSignalingPluginCallKitAPIImpl,
        ZegoSignalingPluginCallKitEventImpl,
        IZegoUIKitPlugin
    implements ZegoSignalingPluginInterface {
  ZegoSignalingPluginEventCenter get eventCenter =>
      ZegoSignalingPluginCore().eventCenter;

  factory ZegoUIKitSignalingPlugin() => instance;

  ZegoUIKitSignalingPlugin._();

  static final ZegoUIKitSignalingPlugin instance = ZegoUIKitSignalingPlugin._();

  /// getPluginType
  @override
  ZegoUIKitPluginType getPluginType() => ZegoUIKitPluginType.signaling;

  /// getVersion
  @override
  Future<String> getVersion() async {
    final zimVersion = await ZIM.getVersion();
    const signalingVersion = 'zego_uikit_signaling_plugin: 2.6.4;';
    if (!kIsWeb && (io.Platform.isAndroid || io.Platform.isIOS)) {
      final zpnsVersion = await ZPNs.getVersion();
      return '$signalingVersion zim:$zimVersion; zpns:$zpnsVersion;';
    } else {
      return '$signalingVersion zim:$zimVersion;';
    }
  }

  /// init
  @override
  Future<void> init({required int appID, String appSign = ''}) async {
    await ZegoSignalingLoggerService().initLog();

    ZegoSignalingLoggerService.logInfo(
      'create ZIM',
      tag: 'signaling',
      subTag: 'init',
    );

    if (null != ZIM.getInstance()) {
      ZegoSignalingLoggerService.logInfo(
        'ZIM is create before',
        tag: 'signaling',
        subTag: 'init',
      );

      return;
    }

    ZIM.create(ZIMAppConfig()
      ..appID = appID
      ..appSign = appSign);
  }

  /// uninit
  @override
  Future<void> uninit() async {
    ZegoSignalingLoggerService.logInfo(
      'destroy ZIM',
      tag: 'signaling',
      subTag: 'uninit',
    );

    ZIM.getInstance()?.destroy();
  }

  /// getErrorEventStream
  @override
  Stream<ZegoSignalingPluginErrorEvent> getErrorEventStream() {
    return ZegoSignalingPluginCore().eventCenter.errorEvent.stream;
  }

  /// getErrorStream
  @override
  Stream<ZegoSignalingError> getErrorStream() {
    return ZegoSignalingPluginCore().errorStreamCtrl?.stream ??
        const Stream.empty();
  }
}
